require "spec_helper"

describe Grognard do
  describe "guard" do
    class OldGuard
      def self.allowed_to(object, subject)
        abilities = []
        abilities << :eat if object == "man" && subject == "chicken"
        abilities
      end
    end

    class YoungGuard
      def self.allowed_to(object, subject)
        [:serve, :cook]
      end
    end

    describe "can?" do
      before do
        @guard = Grognard::Guard.new OldGuard, YoungGuard
      end

      it "should respond to its roles" do
        @guard.should respond_to(:be_a_old_guard)
        @guard.should respond_to(:be_a_young_guard)
      end

      it "should respond if is old guard" do
        @guard.be_a_old_guard
        @guard.should respond_to(:can_eat?)
      end

      it "should respond if is a young guard" do
        @guard.be_a_young_guard
        @guard.should respond_to(:can_serve?)
        @guard.should respond_to(:can_cook?)
      end

      it "be a old guard" do
        @guard.be_a_old_guard
        @guard.can_eat?("man", "chicken").should be_true
        @guard.can_eat?("man", "cat").should be_false
        @guard.can_love?("soldier", "princess").should be_false
      end

      it "be a young guard" do
        @guard.be_a_young_guard
        @guard.can_cook?(:everyone, :everthing).should be_true
        @guard.can_serve?(:everyone, :everthing).should be_true
        @guard.can_rock?(:everyone, :everthing).should be_false
      end

      it "can delete role" do
        @guard.remove_role :old_guard
        @guard.can_be_a_guard?.should be_false
      end
    end
  end
end
